'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _reactIntl = require('react-intl');

exports.default = configContext => {
  var _configContext$inputC = configContext.inputComponents;
  const CompoundInput = _configContext$inputC.CompoundInput,
        OptionPickerInput = _configContext$inputC.OptionPickerInput,
        TextInput = _configContext$inputC.TextInput,
        AutocompleteInput = _configContext$inputC.AutocompleteInput,
        TermPickerInput = _configContext$inputC.TermPickerInput;
  const config = configContext.configHelpers.configKey;
  const DATA_TYPE_FLOAT = configContext.dataTypes.DATA_TYPE_FLOAT;


  return {
    document: {
      'ns2:intakes_lhmc': {
        [config]: {
          service: {
            ns: 'http://collectionspace.org/services/intake/domain/lhmc'
          }
        },
        receivedBy: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.intakes_lhmc.receivedBy.name',
                'defaultMessage': 'Received by'
              }
            }),
            view: {
              type: AutocompleteInput,
              props: {
                source: 'person/local,person/shared,person/ulan,organization/local,organization/shared'
              }
            }
          }
        },
        intakeStatus: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.intakes_lhmc.intakeStatus.name',
                'defaultMessage': 'Intake status'
              }
            }),
            view: {
              type: TermPickerInput,
              props: {
                source: 'intakestatus'
              }
            }
          }
        },
        insuredBy: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.intakes_lhmc.insuredBy.name',
                'defaultMessage': 'Insured by'
              }
            }),
            view: {
              type: OptionPickerInput,
              props: {
                source: 'insuredByValues'
              }
            }
          }
        },
        premiumGroupList: {
          [config]: {
            view: {
              type: CompoundInput
            }
          },
          premiumGroup: {
            [config]: {
              messages: (0, _reactIntl.defineMessages)({
                name: {
                  'id': 'field.intakes_lhmc.premiumGroup.name',
                  'defaultMessage': 'Premium'
                }
              }),
              repeating: true,
              view: {
                type: CompoundInput,
                props: {
                  tabular: true
                }
              }
            },
            premiumCurrency: {
              [config]: {
                messages: (0, _reactIntl.defineMessages)({
                  name: {
                    'id': 'field.intakes_lhmc.premiumCurrency.name',
                    'defaultMessage': 'Currency'
                  },
                  fullName: {
                    'id': 'field.intakes_lhmc.premiumCurrency.fullName',
                    'defaultMessage': 'Premium currency'
                  }
                }),
                view: {
                  type: TermPickerInput,
                  props: {
                    source: 'currency'
                  }
                }
              }
            },
            premiumValue: {
              [config]: {
                dataType: DATA_TYPE_FLOAT,
                messages: (0, _reactIntl.defineMessages)({
                  name: {
                    'id': 'field.intakes_lhmc.premiumValue.name',
                    'defaultMessage': 'Value'
                  },
                  fullName: {
                    'id': 'field.intakes_lhmc.premiumValue.fullName',
                    'defaultMessage': 'Premium value'
                  }
                }),
                view: {
                  type: TextInput
                }
              }
            }
          }
        },
        insuredValueGroupList: {
          [config]: {
            view: {
              type: CompoundInput
            }
          },
          insuredValueGroup: {
            [config]: {
              messages: (0, _reactIntl.defineMessages)({
                name: {
                  'id': 'field.intakes_lhmc.insuredValueGroup.name',
                  'defaultMessage': 'Insured value'
                }
              }),
              repeating: true,
              view: {
                type: CompoundInput,
                props: {
                  tabular: true
                }
              }
            },
            insuredValueCurrency: {
              [config]: {
                messages: (0, _reactIntl.defineMessages)({
                  name: {
                    'id': 'field.intakes_lhmc.insuredValueCurrency.name',
                    'defaultMessage': 'Currency'
                  },
                  fullName: {
                    'id': 'field.intakes_lhmc.insuredValueCurrency.fullName',
                    'defaultMessage': 'Insured value currency'
                  }
                }),
                view: {
                  type: TermPickerInput,
                  props: {
                    source: 'currency'
                  }
                }
              }
            },
            insuredValue: {
              [config]: {
                dataType: DATA_TYPE_FLOAT,
                messages: (0, _reactIntl.defineMessages)({
                  name: {
                    'id': 'field.intakes_lhmc.insuredValue.name',
                    'defaultMessage': 'Value'
                  },
                  fullName: {
                    'id': 'field.intakes_lhmc.insuredValue.fullName',
                    'defaultMessage': 'Insured value'
                  }
                }),
                view: {
                  type: TextInput
                }
              }
            }
          }
        },
        inventoriedBy: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.intakes_lhmc.inventoriedBy.name',
                'defaultMessage': 'Inventoried by'
              }
            }),
            view: {
              type: AutocompleteInput,
              props: {
                source: 'person/local,person/shared,person/ulan'
              }
            }
          }
        },
        intakeCondition: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.intakes_lhmc.intakeCondition.name',
                'defaultMessage': 'Condition'
              }
            }),
            view: {
              type: TermPickerInput,
              props: {
                source: 'condition'
              }
            }
          }
        }
      }
    }
  };
};