'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _reactIntl = require('react-intl');

exports.default = configContext => {
  var _configContext$inputC = configContext.inputComponents;
  const AutocompleteInput = _configContext$inputC.AutocompleteInput,
        CompoundInput = _configContext$inputC.CompoundInput,
        TermPickerInput = _configContext$inputC.TermPickerInput,
        TextInput = _configContext$inputC.TextInput;
  const config = configContext.configHelpers.configKey;


  return {
    document: {
      'ns2:persons_common': {
        birthPlace: {
          [config]: {
            messages: {
              // Add a fullName message
              fullName: {
                id: 'field.persons_common.birthPlace.fullName',
                defaultMessage: 'Where born'
              }
            },
            view: {
              type: AutocompleteInput,
              props: {
                source: 'place/local,place/tgn'
              }
            }
          }
        },
        deathPlace: {
          [config]: {
            messages: {
              // Add a fullName message
              fullName: {
                id: 'field.persons_common.deathPlace.fullName',
                defaultMessage: 'Where died'
              }
            },
            view: {
              type: AutocompleteInput,
              props: {
                source: 'place/local,place/tgn'
              }
            }
          }
        }
      },
      'ns2:persons_lhmc': {
        [config]: {
          service: {
            ns: 'http://collectionspace.org/services/person/domain/lhmc'
          }
        },
        relatedPerson: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.persons_lhmc.relatedPerson.name',
                'defaultMessage': 'Name'
              },
              fullName: {
                'id': 'field.persons_lhmc.relatedPerson.fullName',
                'defaultMessage': 'Related person name'
              }
            }),
            view: {
              type: AutocompleteInput,
              props: {
                source: 'person/local,person/ulan,person/shared'
              }
            }
          }
        },
        relationshipType: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.persons_lhmc.relationshipType.name',
                'defaultMessage': 'Type'
              },
              fullName: {
                'id': 'field.persons_lhmc.relationshipType.fullName',
                'defaultMessage': 'Related person type'
              }
            }),
            view: {
              type: TermPickerInput,
              props: {
                source: 'personrelationship'
              }
            }
          }
        },
        relationshipNote: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.persons_lhmc.relationshipNote.name',
                'defaultMessage': 'Note'
              },
              fullName: {
                'id': 'field.persons_lhmc.relationshipNote.fullName',
                'defaultMessage': 'Related person note'
              }
            }),
            view: {
              type: TextInput
            }
          }
        },
        placeOrResidence: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.persons_lhmc.placeOrResidence.name',
                'defaultMessage': 'Name'
              },
              fullName: {
                'id': 'field.persons_lhmc.placeOrResidence.fullName',
                'defaultMessage': 'Place name'
              }
            }),
            view: {
              type: AutocompleteInput,
              props: {
                source: 'place/local,place/tgn,place/shared'
              }
            }
          }
        },
        placeNote: {
          [config]: {
            messages: (0, _reactIntl.defineMessages)({
              name: {
                'id': 'field.persons_lhmc.placeNote.name',
                'defaultMessage': 'Note'
              },
              fullName: {
                'id': 'field.persons_lhmc.placeNote.fullName',
                'defaultMessage': 'Place note'
              }
            }),
            view: {
              type: TextInput
            }
          }
        },
        publicationsPersonGroupList: {
          // This whole group was misnamed in 4.x. It's a citation, not a person.
          [config]: {
            view: {
              type: CompoundInput
            }
          },
          publicationsPersonGroup: {
            [config]: {
              messages: (0, _reactIntl.defineMessages)({
                name: {
                  'id': 'field.persons_lhmc.publicationsPersonGroup.name',
                  'defaultMessage': 'Publication'
                }
              }),
              repeating: true,
              view: {
                type: CompoundInput,
                props: {
                  tabular: true
                }
              }
            },
            publicationsPerson: {
              [config]: {
                messages: (0, _reactIntl.defineMessages)({
                  name: {
                    'id': 'field.persons_lhmc.publicationsPerson.name',
                    'defaultMessage': 'Name'
                  },
                  fullName: {
                    'id': 'field.persons_lhmc.publicationsPerson.fullName',
                    'defaultMessage': 'Publication name'
                  }
                }),
                view: {
                  type: AutocompleteInput,
                  props: {
                    source: 'citation/local,citation/worldcat,citation/shared'
                  }
                }
              }
            },
            publicationsPersonNote: {
              [config]: {
                messages: (0, _reactIntl.defineMessages)({
                  name: {
                    'id': 'field.persons_lhmc.publicationsPersonNote.name',
                    'defaultMessage': 'Note'
                  },
                  fullName: {
                    'id': 'field.persons_lhmc.publicationsPersonNote.fullName',
                    'defaultMessage': 'Publication note'
                  }
                }),
                view: {
                  type: TextInput
                }
              }
            }
          }
        }
      }
    }
  };
};